pydivide Tutorial
Downloading Key Parameter Data
Storing Data
Standard Plots
Time-series plotting routine
Altitude Plots
Plotting of In-situ data on a Lat/Lon Map

Downloading Data

- This command will download the MAVEN KP data into a directory structure on your machine that the Toolkit will remember (in the mvn_toolkit_prefs.txt file):
- pydivide.mvn_kp_download_files(start_date='2015-01-15', end_date='2015-02-15')
- A similar command can be used to download all other science data:
- pydivide.mvn_kp_download_sci_files(start_date='2015-01-15', end_date='2015-02-15', instrument='ngi', level='l2')
- instrument can be any of "lpw, ngi, euv, sta, swi, swe, mag, iuv, sep" and level can be any of "l1a, l1b, l1c, l2, or l3"

Storing Data

- This procedure will read in KP files and store them in a variable.
- insitu = pydivide.mvn_kp_read(['2015-04-10', '2015-05-10'])
- The result of this command is all KP data between April 10th and May 10th is stored in the "insitu" variable.

Standard Plots

- For a quick look at the dataset, you can use the following command to look at common plots:
- pydivide.mvn_kp_standards(insitu, all_plots=True)
- If you would like a subset of the 25 plots, add "list_plots=True" to the command, and it will list all of the plots that you can set to true for a subset of the plot. For example, pydivide.mvn_kp_standards(x, ngims_neutral=True, euv=True, ionosphere=True, sep_ion=True, sun_bar=True)

MAVEN time-series plotting routine

- Plot any parameter contained within the KP data may be plotted as a time series.
- pydivide.mvn_kp_plot(insitu, parameter='SWEA.Solar Wind Electron Density')

Altitude Plots

- Plot any Key Parameter against altitude. Syntax is the same as mvn_kp_plot.
- pydivide.mvn_kp_alt_plot(insitu, parameter='SWEA.Solar Wind Electron Density')

Plotting of In-situ data on a Lat/Lon Map

- Plot the H+ density from SWIA atop a map of Mars displaying the MOLA altimetry.
- pydivide.mvn_kp_map2d(insitu, parameter='SWEA.Solar Wind Electron Density')